@@ -332,7 +332,7 @@ p11_dl_error (void)
 			MAKELANGID (LANG_NEUTRAL, SUBLANG_DEFAULT),
 			(LPSTR)&msg_buf, 0, NULL);
 
-	if (msg_buf == NULL);
+	if (msg_buf == NULL)
 		return NULL;
 
 	result = strdup (msg_buf);
@@ -859,7 +859,7 @@ mkdtemp (char *template)
 #ifndef HAVE_GETAUXVAL
 
 unsigned long
-getauxval (unsigned long type)
+_p11_getauxval (unsigned long type)
 {
 	static unsigned long secure = 0UL;
 	static bool check_secure_initialized = false;
@@ -871,7 +871,7 @@ getauxval (unsigned long type)
 	assert (type == AT_SECURE);
 
 	if (!check_secure_initialized) {
-#if defined(HAVE___LIBC_ENABLE_SECURE)
+#if defined(HAVE___LIBC_ENABLE_SECURE) && !defined(__GNU__)
 		extern int __libc_enable_secure;
 		secure = __libc_enable_secure;
 
@@ -908,7 +908,7 @@ getauxval (unsigned long type)
 char *
 secure_getenv (const char *name)
 {
-	if (getauxval (AT_SECURE))
+	if (_p11_getauxval (AT_SECURE))
 		return NULL;
 	return getenv (name);
 }
